// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: performance_metrics.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_performance_5fmetrics_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_performance_5fmetrics_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3019000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3019004 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#ifndef _MSC_VER
#pragma GCC system_header
#pragma GCC diagnostic ignored "-Wshadow"
#pragma GCC diagnostic ignored "-Wunused-parameter"
#endif
#include <boost/shared_ptr.hpp>
#include <gazebo/util/system.hh>
#include "gazebo/msgs/MsgFactory.hh"
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_performance_5fmetrics_2eproto GZ_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct GZ_MSGS_VISIBLE TableStruct_performance_5fmetrics_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[2]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const uint32_t offsets[];
};
GZ_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_performance_5fmetrics_2eproto;
namespace gazebo {
namespace msgs {
class PerformanceMetrics;
struct PerformanceMetricsDefaultTypeInternal;
GZ_MSGS_VISIBLE extern PerformanceMetricsDefaultTypeInternal _PerformanceMetrics_default_instance_;
class PerformanceMetrics_PerformanceSensorMetrics;
struct PerformanceMetrics_PerformanceSensorMetricsDefaultTypeInternal;
GZ_MSGS_VISIBLE extern PerformanceMetrics_PerformanceSensorMetricsDefaultTypeInternal _PerformanceMetrics_PerformanceSensorMetrics_default_instance_;
}  // namespace msgs
}  // namespace gazebo
PROTOBUF_NAMESPACE_OPEN
template<> GZ_MSGS_VISIBLE ::gazebo::msgs::PerformanceMetrics* Arena::CreateMaybeMessage<::gazebo::msgs::PerformanceMetrics>(Arena*);
template<> GZ_MSGS_VISIBLE ::gazebo::msgs::PerformanceMetrics_PerformanceSensorMetrics* Arena::CreateMaybeMessage<::gazebo::msgs::PerformanceMetrics_PerformanceSensorMetrics>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace gazebo {
namespace msgs {

// ===================================================================

class GZ_MSGS_VISIBLE PerformanceMetrics_PerformanceSensorMetrics final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:gazebo.msgs.PerformanceMetrics.PerformanceSensorMetrics) */ {
 public:
  inline PerformanceMetrics_PerformanceSensorMetrics() : PerformanceMetrics_PerformanceSensorMetrics(nullptr) {}
  ~PerformanceMetrics_PerformanceSensorMetrics() override;
  explicit constexpr PerformanceMetrics_PerformanceSensorMetrics(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  PerformanceMetrics_PerformanceSensorMetrics(const PerformanceMetrics_PerformanceSensorMetrics& from);
  PerformanceMetrics_PerformanceSensorMetrics(PerformanceMetrics_PerformanceSensorMetrics&& from) noexcept
    : PerformanceMetrics_PerformanceSensorMetrics() {
    *this = ::std::move(from);
  }

  inline PerformanceMetrics_PerformanceSensorMetrics& operator=(const PerformanceMetrics_PerformanceSensorMetrics& from) {
    CopyFrom(from);
    return *this;
  }
  inline PerformanceMetrics_PerformanceSensorMetrics& operator=(PerformanceMetrics_PerformanceSensorMetrics&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet& unknown_fields() const {
    return _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance);
  }
  inline ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet* mutable_unknown_fields() {
    return _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const PerformanceMetrics_PerformanceSensorMetrics& default_instance() {
    return *internal_default_instance();
  }
  static inline const PerformanceMetrics_PerformanceSensorMetrics* internal_default_instance() {
    return reinterpret_cast<const PerformanceMetrics_PerformanceSensorMetrics*>(
               &_PerformanceMetrics_PerformanceSensorMetrics_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(PerformanceMetrics_PerformanceSensorMetrics& a, PerformanceMetrics_PerformanceSensorMetrics& b) {
    a.Swap(&b);
  }
  inline void Swap(PerformanceMetrics_PerformanceSensorMetrics* other) {
    if (other == this) return;
  #ifdef PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() != nullptr &&
        GetOwningArena() == other->GetOwningArena()) {
   #else  // PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() == other->GetOwningArena()) {
  #endif  // !PROTOBUF_FORCE_COPY_IN_SWAP
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(PerformanceMetrics_PerformanceSensorMetrics* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  PerformanceMetrics_PerformanceSensorMetrics* New(::PROTOBUF_NAMESPACE_ID::Arena* arena = nullptr) const final {
    return CreateMaybeMessage<PerformanceMetrics_PerformanceSensorMetrics>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const PerformanceMetrics_PerformanceSensorMetrics& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const PerformanceMetrics_PerformanceSensorMetrics& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  uint8_t* _InternalSerialize(
      uint8_t* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(PerformanceMetrics_PerformanceSensorMetrics* other);

  private:
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "gazebo.msgs.PerformanceMetrics.PerformanceSensorMetrics";
  }
  protected:
  explicit PerformanceMetrics_PerformanceSensorMetrics(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kNameFieldNumber = 1,
    kRealUpdateRateFieldNumber = 2,
    kSimUpdateRateFieldNumber = 3,
    kFpsFieldNumber = 4,
  };
  // required string name = 1;
  bool has_name() const;
  private:
  bool _internal_has_name() const;
  public:
  void clear_name();
  const std::string& name() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_name(ArgT0&& arg0, ArgT... args);
  std::string* mutable_name();
  PROTOBUF_NODISCARD std::string* release_name();
  void set_allocated_name(std::string* name);
  private:
  const std::string& _internal_name() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_name(const std::string& value);
  std::string* _internal_mutable_name();
  public:

  // required double real_update_rate = 2;
  bool has_real_update_rate() const;
  private:
  bool _internal_has_real_update_rate() const;
  public:
  void clear_real_update_rate();
  double real_update_rate() const;
  void set_real_update_rate(double value);
  private:
  double _internal_real_update_rate() const;
  void _internal_set_real_update_rate(double value);
  public:

  // required double sim_update_rate = 3;
  bool has_sim_update_rate() const;
  private:
  bool _internal_has_sim_update_rate() const;
  public:
  void clear_sim_update_rate();
  double sim_update_rate() const;
  void set_sim_update_rate(double value);
  private:
  double _internal_sim_update_rate() const;
  void _internal_set_sim_update_rate(double value);
  public:

  // optional double fps = 4;
  bool has_fps() const;
  private:
  bool _internal_has_fps() const;
  public:
  void clear_fps();
  double fps() const;
  void set_fps(double value);
  private:
  double _internal_fps() const;
  void _internal_set_fps(double value);
  public:

  // @@protoc_insertion_point(class_scope:gazebo.msgs.PerformanceMetrics.PerformanceSensorMetrics)
 private:
  class _Internal;

  // helper for ByteSizeLong()
  size_t RequiredFieldsByteSizeFallback() const;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::HasBits<1> _has_bits_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr name_;
  double real_update_rate_;
  double sim_update_rate_;
  double fps_;
  friend struct ::TableStruct_performance_5fmetrics_2eproto;
};
// -------------------------------------------------------------------

class GZ_MSGS_VISIBLE PerformanceMetrics final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:gazebo.msgs.PerformanceMetrics) */ {
 public:
  inline PerformanceMetrics() : PerformanceMetrics(nullptr) {}
  ~PerformanceMetrics() override;
  explicit constexpr PerformanceMetrics(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  PerformanceMetrics(const PerformanceMetrics& from);
  PerformanceMetrics(PerformanceMetrics&& from) noexcept
    : PerformanceMetrics() {
    *this = ::std::move(from);
  }

  inline PerformanceMetrics& operator=(const PerformanceMetrics& from) {
    CopyFrom(from);
    return *this;
  }
  inline PerformanceMetrics& operator=(PerformanceMetrics&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet& unknown_fields() const {
    return _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance);
  }
  inline ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet* mutable_unknown_fields() {
    return _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const PerformanceMetrics& default_instance() {
    return *internal_default_instance();
  }
  static inline const PerformanceMetrics* internal_default_instance() {
    return reinterpret_cast<const PerformanceMetrics*>(
               &_PerformanceMetrics_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    1;

  friend void swap(PerformanceMetrics& a, PerformanceMetrics& b) {
    a.Swap(&b);
  }
  inline void Swap(PerformanceMetrics* other) {
    if (other == this) return;
  #ifdef PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() != nullptr &&
        GetOwningArena() == other->GetOwningArena()) {
   #else  // PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() == other->GetOwningArena()) {
  #endif  // !PROTOBUF_FORCE_COPY_IN_SWAP
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(PerformanceMetrics* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  PerformanceMetrics* New(::PROTOBUF_NAMESPACE_ID::Arena* arena = nullptr) const final {
    return CreateMaybeMessage<PerformanceMetrics>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const PerformanceMetrics& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const PerformanceMetrics& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  uint8_t* _InternalSerialize(
      uint8_t* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(PerformanceMetrics* other);

  private:
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "gazebo.msgs.PerformanceMetrics";
  }
  protected:
  explicit PerformanceMetrics(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  typedef PerformanceMetrics_PerformanceSensorMetrics PerformanceSensorMetrics;

  // accessors -------------------------------------------------------

  enum : int {
    kSensorFieldNumber = 2,
    kRealTimeFactorFieldNumber = 1,
  };
  // repeated .gazebo.msgs.PerformanceMetrics.PerformanceSensorMetrics sensor = 2;
  int sensor_size() const;
  private:
  int _internal_sensor_size() const;
  public:
  void clear_sensor();
  ::gazebo::msgs::PerformanceMetrics_PerformanceSensorMetrics* mutable_sensor(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::gazebo::msgs::PerformanceMetrics_PerformanceSensorMetrics >*
      mutable_sensor();
  private:
  const ::gazebo::msgs::PerformanceMetrics_PerformanceSensorMetrics& _internal_sensor(int index) const;
  ::gazebo::msgs::PerformanceMetrics_PerformanceSensorMetrics* _internal_add_sensor();
  public:
  const ::gazebo::msgs::PerformanceMetrics_PerformanceSensorMetrics& sensor(int index) const;
  ::gazebo::msgs::PerformanceMetrics_PerformanceSensorMetrics* add_sensor();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::gazebo::msgs::PerformanceMetrics_PerformanceSensorMetrics >&
      sensor() const;

  // required double real_time_factor = 1 [default = 0];
  bool has_real_time_factor() const;
  private:
  bool _internal_has_real_time_factor() const;
  public:
  void clear_real_time_factor();
  double real_time_factor() const;
  void set_real_time_factor(double value);
  private:
  double _internal_real_time_factor() const;
  void _internal_set_real_time_factor(double value);
  public:

  // @@protoc_insertion_point(class_scope:gazebo.msgs.PerformanceMetrics)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::HasBits<1> _has_bits_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::gazebo::msgs::PerformanceMetrics_PerformanceSensorMetrics > sensor_;
  double real_time_factor_;
  friend struct ::TableStruct_performance_5fmetrics_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// PerformanceMetrics_PerformanceSensorMetrics

// required string name = 1;
inline bool PerformanceMetrics_PerformanceSensorMetrics::_internal_has_name() const {
  bool value = (_has_bits_[0] & 0x00000001u) != 0;
  return value;
}
inline bool PerformanceMetrics_PerformanceSensorMetrics::has_name() const {
  return _internal_has_name();
}
inline void PerformanceMetrics_PerformanceSensorMetrics::clear_name() {
  name_.ClearToEmpty();
  _has_bits_[0] &= ~0x00000001u;
}
inline const std::string& PerformanceMetrics_PerformanceSensorMetrics::name() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.PerformanceMetrics.PerformanceSensorMetrics.name)
  return _internal_name();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void PerformanceMetrics_PerformanceSensorMetrics::set_name(ArgT0&& arg0, ArgT... args) {
 _has_bits_[0] |= 0x00000001u;
 name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:gazebo.msgs.PerformanceMetrics.PerformanceSensorMetrics.name)
}
inline std::string* PerformanceMetrics_PerformanceSensorMetrics::mutable_name() {
  std::string* _s = _internal_mutable_name();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.PerformanceMetrics.PerformanceSensorMetrics.name)
  return _s;
}
inline const std::string& PerformanceMetrics_PerformanceSensorMetrics::_internal_name() const {
  return name_.Get();
}
inline void PerformanceMetrics_PerformanceSensorMetrics::_internal_set_name(const std::string& value) {
  _has_bits_[0] |= 0x00000001u;
  name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* PerformanceMetrics_PerformanceSensorMetrics::_internal_mutable_name() {
  _has_bits_[0] |= 0x00000001u;
  return name_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* PerformanceMetrics_PerformanceSensorMetrics::release_name() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.PerformanceMetrics.PerformanceSensorMetrics.name)
  if (!_internal_has_name()) {
    return nullptr;
  }
  _has_bits_[0] &= ~0x00000001u;
  auto* p = name_.ReleaseNonDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
#ifdef PROTOBUF_FORCE_COPY_DEFAULT_STRING
  if (name_.IsDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited())) {
    name_.Set(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), "", GetArenaForAllocation());
  }
#endif // PROTOBUF_FORCE_COPY_DEFAULT_STRING
  return p;
}
inline void PerformanceMetrics_PerformanceSensorMetrics::set_allocated_name(std::string* name) {
  if (name != nullptr) {
    _has_bits_[0] |= 0x00000001u;
  } else {
    _has_bits_[0] &= ~0x00000001u;
  }
  name_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), name,
      GetArenaForAllocation());
#ifdef PROTOBUF_FORCE_COPY_DEFAULT_STRING
  if (name_.IsDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited())) {
    name_.Set(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), "", GetArenaForAllocation());
  }
#endif // PROTOBUF_FORCE_COPY_DEFAULT_STRING
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.PerformanceMetrics.PerformanceSensorMetrics.name)
}

// required double real_update_rate = 2;
inline bool PerformanceMetrics_PerformanceSensorMetrics::_internal_has_real_update_rate() const {
  bool value = (_has_bits_[0] & 0x00000002u) != 0;
  return value;
}
inline bool PerformanceMetrics_PerformanceSensorMetrics::has_real_update_rate() const {
  return _internal_has_real_update_rate();
}
inline void PerformanceMetrics_PerformanceSensorMetrics::clear_real_update_rate() {
  real_update_rate_ = 0;
  _has_bits_[0] &= ~0x00000002u;
}
inline double PerformanceMetrics_PerformanceSensorMetrics::_internal_real_update_rate() const {
  return real_update_rate_;
}
inline double PerformanceMetrics_PerformanceSensorMetrics::real_update_rate() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.PerformanceMetrics.PerformanceSensorMetrics.real_update_rate)
  return _internal_real_update_rate();
}
inline void PerformanceMetrics_PerformanceSensorMetrics::_internal_set_real_update_rate(double value) {
  _has_bits_[0] |= 0x00000002u;
  real_update_rate_ = value;
}
inline void PerformanceMetrics_PerformanceSensorMetrics::set_real_update_rate(double value) {
  _internal_set_real_update_rate(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.PerformanceMetrics.PerformanceSensorMetrics.real_update_rate)
}

// required double sim_update_rate = 3;
inline bool PerformanceMetrics_PerformanceSensorMetrics::_internal_has_sim_update_rate() const {
  bool value = (_has_bits_[0] & 0x00000004u) != 0;
  return value;
}
inline bool PerformanceMetrics_PerformanceSensorMetrics::has_sim_update_rate() const {
  return _internal_has_sim_update_rate();
}
inline void PerformanceMetrics_PerformanceSensorMetrics::clear_sim_update_rate() {
  sim_update_rate_ = 0;
  _has_bits_[0] &= ~0x00000004u;
}
inline double PerformanceMetrics_PerformanceSensorMetrics::_internal_sim_update_rate() const {
  return sim_update_rate_;
}
inline double PerformanceMetrics_PerformanceSensorMetrics::sim_update_rate() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.PerformanceMetrics.PerformanceSensorMetrics.sim_update_rate)
  return _internal_sim_update_rate();
}
inline void PerformanceMetrics_PerformanceSensorMetrics::_internal_set_sim_update_rate(double value) {
  _has_bits_[0] |= 0x00000004u;
  sim_update_rate_ = value;
}
inline void PerformanceMetrics_PerformanceSensorMetrics::set_sim_update_rate(double value) {
  _internal_set_sim_update_rate(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.PerformanceMetrics.PerformanceSensorMetrics.sim_update_rate)
}

// optional double fps = 4;
inline bool PerformanceMetrics_PerformanceSensorMetrics::_internal_has_fps() const {
  bool value = (_has_bits_[0] & 0x00000008u) != 0;
  return value;
}
inline bool PerformanceMetrics_PerformanceSensorMetrics::has_fps() const {
  return _internal_has_fps();
}
inline void PerformanceMetrics_PerformanceSensorMetrics::clear_fps() {
  fps_ = 0;
  _has_bits_[0] &= ~0x00000008u;
}
inline double PerformanceMetrics_PerformanceSensorMetrics::_internal_fps() const {
  return fps_;
}
inline double PerformanceMetrics_PerformanceSensorMetrics::fps() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.PerformanceMetrics.PerformanceSensorMetrics.fps)
  return _internal_fps();
}
inline void PerformanceMetrics_PerformanceSensorMetrics::_internal_set_fps(double value) {
  _has_bits_[0] |= 0x00000008u;
  fps_ = value;
}
inline void PerformanceMetrics_PerformanceSensorMetrics::set_fps(double value) {
  _internal_set_fps(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.PerformanceMetrics.PerformanceSensorMetrics.fps)
}

// -------------------------------------------------------------------

// PerformanceMetrics

// required double real_time_factor = 1 [default = 0];
inline bool PerformanceMetrics::_internal_has_real_time_factor() const {
  bool value = (_has_bits_[0] & 0x00000001u) != 0;
  return value;
}
inline bool PerformanceMetrics::has_real_time_factor() const {
  return _internal_has_real_time_factor();
}
inline void PerformanceMetrics::clear_real_time_factor() {
  real_time_factor_ = 0;
  _has_bits_[0] &= ~0x00000001u;
}
inline double PerformanceMetrics::_internal_real_time_factor() const {
  return real_time_factor_;
}
inline double PerformanceMetrics::real_time_factor() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.PerformanceMetrics.real_time_factor)
  return _internal_real_time_factor();
}
inline void PerformanceMetrics::_internal_set_real_time_factor(double value) {
  _has_bits_[0] |= 0x00000001u;
  real_time_factor_ = value;
}
inline void PerformanceMetrics::set_real_time_factor(double value) {
  _internal_set_real_time_factor(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.PerformanceMetrics.real_time_factor)
}

// repeated .gazebo.msgs.PerformanceMetrics.PerformanceSensorMetrics sensor = 2;
inline int PerformanceMetrics::_internal_sensor_size() const {
  return sensor_.size();
}
inline int PerformanceMetrics::sensor_size() const {
  return _internal_sensor_size();
}
inline void PerformanceMetrics::clear_sensor() {
  sensor_.Clear();
}
inline ::gazebo::msgs::PerformanceMetrics_PerformanceSensorMetrics* PerformanceMetrics::mutable_sensor(int index) {
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.PerformanceMetrics.sensor)
  return sensor_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::gazebo::msgs::PerformanceMetrics_PerformanceSensorMetrics >*
PerformanceMetrics::mutable_sensor() {
  // @@protoc_insertion_point(field_mutable_list:gazebo.msgs.PerformanceMetrics.sensor)
  return &sensor_;
}
inline const ::gazebo::msgs::PerformanceMetrics_PerformanceSensorMetrics& PerformanceMetrics::_internal_sensor(int index) const {
  return sensor_.Get(index);
}
inline const ::gazebo::msgs::PerformanceMetrics_PerformanceSensorMetrics& PerformanceMetrics::sensor(int index) const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.PerformanceMetrics.sensor)
  return _internal_sensor(index);
}
inline ::gazebo::msgs::PerformanceMetrics_PerformanceSensorMetrics* PerformanceMetrics::_internal_add_sensor() {
  return sensor_.Add();
}
inline ::gazebo::msgs::PerformanceMetrics_PerformanceSensorMetrics* PerformanceMetrics::add_sensor() {
  ::gazebo::msgs::PerformanceMetrics_PerformanceSensorMetrics* _add = _internal_add_sensor();
  // @@protoc_insertion_point(field_add:gazebo.msgs.PerformanceMetrics.sensor)
  return _add;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::gazebo::msgs::PerformanceMetrics_PerformanceSensorMetrics >&
PerformanceMetrics::sensor() const {
  // @@protoc_insertion_point(field_list:gazebo.msgs.PerformanceMetrics.sensor)
  return sensor_;
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__
// -------------------------------------------------------------------


typedef boost::shared_ptr<gazebo::msgs::PerformanceMetrics> PerformanceMetricsPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace gazebo

typedef const boost::shared_ptr<gazebo::msgs::PerformanceMetrics const> ConstPerformanceMetricsPtr;
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_performance_5fmetrics_2eproto
